@@ -11,7 +11,7 @@ from . import test_MultiChannelAnalogInput
 # This function is called by unittest.main
 # Do no delete !!!!
 def load_tests(loader, standard_tests, pattern):
-    for name, elm in globals().items():
+    for name, elm in list(globals().items()):
         if name.startswith('test') and isinstance(elm, ModuleType):        
             suite = loader.loadTestsFromModule(elm)
             standard_tests.addTests(suite)
